@@ -176,33 +176,21 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
                    GCancellable       *cancellable,
                    GError            **error)
 {
-  GError *identity_error;
-  RestProxy *proxy;
-  RestProxyCall *call;
-  JsonParser *parser;
+  GError *identity_error = NULL;
+  RestProxy *proxy = NULL;
+  RestProxyCall *call = NULL;
+  JsonParser *parser = NULL;
   JsonObject *json_object;
-  gchar *ret;
-  gchar *id;
-  gchar *presentation_identity;
-
-  ret = NULL;
-
-  identity_error = NULL;
-  proxy = NULL;
-  call = NULL;
-  parser = NULL;
-  id = NULL;
-  presentation_identity = NULL;
+  gchar *ret = NULL;
+  gchar *id = NULL;
+  gchar *presentation_identity = NULL;
 
   /* TODO: cancellable */
 
   proxy = rest_proxy_new ("https://graph.facebook.com/me", FALSE);
   call = rest_proxy_new_call (proxy);
   rest_proxy_call_set_method (call, "GET");
-  rest_proxy_call_add_params (call,
-                              "access_token", access_token,
-                              "fields", "id,email",
-                              NULL);
+  rest_proxy_call_add_param (call, "access_token", access_token);
 
   if (!rest_proxy_call_sync (call, error))
     goto out;
@@ -240,7 +228,8 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
     }
 
   json_object = json_node_get_object (json_parser_get_root (parser));
-  if (!json_object_has_member (json_object, "id"))
+  id = g_strdup (json_object_get_string_member (json_object, "id"));
+  if (id == NULL)
     {
       g_warning ("Did not find id in JSON data");
       g_set_error (error,
@@ -249,15 +238,20 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
                    _("Could not parse response"));
       goto out;
     }
-  if (!json_object_has_member (json_object, "email"))
-    {
-      g_warning ("Did not find email in JSON data");
-      g_set_error (error, GOA_ERROR, GOA_ERROR_FAILED, _("Could not parse response"));
-      goto out;
-    }
-
-  id = g_strdup (json_object_get_string_member (json_object, "id"));
   presentation_identity = g_strdup (json_object_get_string_member (json_object, "email"));
+  if (presentation_identity == NULL)
+    {
+      presentation_identity = g_strdup (json_object_get_string_member (json_object, "username"));
+      if (presentation_identity == NULL)
+        {
+          g_warning ("Did not find email or username in JSON data");
+          g_set_error (error,
+                       GOA_ERROR,
+                       GOA_ERROR_FAILED,
+                       _("Could not parse response"));
+          goto out;
+        }
+    }
 
   ret = id;
   id = NULL;
@@ -282,14 +276,9 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
 static gboolean
 is_identity_node (GoaOAuth2Provider *oauth2_provider, WebKitDOMHTMLInputElement *element)
 {
-  gboolean ret;
-  gchar *element_type;
-  gchar *name;
-
-  element_type = NULL;
-  name = NULL;
-
-  ret = FALSE;
+  gboolean ret = FALSE;
+  gchar *element_type = NULL;
+  gchar *name = NULL;
 
   g_object_get (element, "type", &element_type, NULL);
   if (g_strcmp0 (element_type, "text") != 0)
@@ -318,13 +307,11 @@ build_object (GoaProvider         *provider,
               gboolean             just_added,
               GError             **error)
 {
-  GoaAccount *account;
+  GoaAccount *account = NULL;
   gboolean photos_enabled;
   gboolean maps_enabled;
   gboolean ret = FALSE;
 
-  account = NULL;
-
   /* Chain up */
   if (!GOA_PROVIDER_CLASS (goa_facebook_provider_parent_class)->build_object (provider,
                                                                               object,
