@@ -193,21 +193,13 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
                    GCancellable       *cancellable,
                    GError            **error)
 {
-  GError *identity_error;
-  RestProxy *proxy;
-  RestProxyCall *call;
-  JsonParser *parser;
+  GError *identity_error = NULL;
+  RestProxy *proxy = NULL;
+  RestProxyCall *call = NULL;
+  JsonParser *parser = NULL;
   JsonObject *json_object;
-  gchar *ret;
-  gchar *email;
-
-  ret = NULL;
-
-  identity_error = NULL;
-  proxy = NULL;
-  call = NULL;
-  parser = NULL;
-  email = NULL;
+  gchar *ret = NULL;
+  gchar *email = NULL;
 
   /* TODO: cancellable */
 
@@ -278,27 +270,21 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
 static gboolean
 is_identity_node (GoaOAuth2Provider *oauth2_provider, WebKitDOMHTMLInputElement *element)
 {
-  gboolean ret;
-  gchar *element_type;
-  gchar *id;
-  gchar *name;
-
-  element_type = NULL;
-  id = NULL;
-  name = NULL;
-
-  ret = FALSE;
+  gboolean ret = FALSE;
+  gchar *element_type = NULL;
+  gchar *id = NULL;
+  gchar *name = NULL;
 
   g_object_get (element, "type", &element_type, NULL);
   if (g_strcmp0 (element_type, "email") != 0)
     goto out;
 
   id = webkit_dom_element_get_id (WEBKIT_DOM_ELEMENT (element));
-  if (g_strcmp0 (id, "identifierId") != 0)
+  if (g_strcmp0 (id, "Email") != 0)
     goto out;
 
   name = webkit_dom_html_input_element_get_name (element);
-  if (g_strcmp0 (name, "identifier") != 0)
+  if (g_strcmp0 (name, "Email") != 0)
     goto out;
 
   ret = TRUE;
@@ -321,11 +307,11 @@ build_object (GoaProvider         *provider,
               gboolean             just_added,
               GError             **error)
 {
-  GoaAccount *account;
-  GoaMail *mail;
+  GoaAccount *account = NULL;
+  GoaMail *mail = NULL;
   gchar *uri_caldav;
   gchar *uri_drive;
-  gboolean ret;
+  gboolean ret = FALSE;
   gboolean mail_enabled;
   gboolean calendar_enabled;
   gboolean contacts_enabled;
@@ -336,10 +322,6 @@ build_object (GoaProvider         *provider,
   gboolean printers_enabled;
   const gchar *email_address;
 
-  account = NULL;
-  mail = NULL;
-  ret = FALSE;
-
   /* Chain up */
   if (!GOA_PROVIDER_CLASS (goa_google_provider_parent_class)->build_object (provider,
                                                                             object,
