@@ -60,8 +60,9 @@ static char *sign_in_identity_sync (GoaKerberosProvider  *self,
                                     const char           *preauth_source,
                                     GCancellable         *cancellable,
                                     GError              **error);
-static void sign_in_thread (GSimpleAsyncResult  *result,
+static void sign_in_thread (GTask               *result,
                             GoaKerberosProvider *self,
+                            gpointer             task_data,
                             GCancellable        *cancellable);
 static GoaIdentityServiceIdentity *get_identity_from_object_manager (GoaKerberosProvider *self,
                                                                      const char          *identifier);
@@ -218,19 +219,11 @@ sign_in_identity (GoaKerberosProvider  *self,
                   GAsyncReadyCallback   callback,
                   gpointer              user_data)
 {
-  GSimpleAsyncResult *operation_result;
+  GTask *operation_result;
 
-  operation_result = g_simple_async_result_new (G_OBJECT (self),
-                                                callback,
-                                                user_data,
-                                                (gpointer)
-                                                identifier);
+  operation_result = g_task_new (G_OBJECT (self), cancellable, callback, user_data);
+  g_task_set_source_tag (operation_result, (gpointer) identifier);
 
-  g_simple_async_result_set_check_cancellable (operation_result, cancellable);
-
-  g_object_set_data (G_OBJECT (operation_result),
-                     "cancellable",
-                     cancellable);
   g_object_set_data (G_OBJECT (operation_result),
                      "password",
                      (gpointer)
@@ -239,11 +232,9 @@ sign_in_identity (GoaKerberosProvider  *self,
                           "preauthentication-source",
                           g_strdup (preauth_source),
                           g_free);
-  g_simple_async_result_run_in_thread (operation_result,
-                                       (GSimpleAsyncThreadFunc)
-                                       sign_in_thread,
-                                       G_PRIORITY_DEFAULT,
-                                       cancellable);
+  g_task_run_in_thread (operation_result, (GTaskThreadFunc) sign_in_thread);
+
+  g_object_unref (operation_result);
 }
 
 static void
@@ -251,13 +242,7 @@ on_account_signed_in (GoaProvider   *provider,
                       GAsyncResult  *result,
                       SignInRequest *request)
 {
-  if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result),
-                                             &request->error))
-    {
-      g_main_loop_quit (request->loop);
-      return;
-    }
-
+  g_task_propagate_boolean (G_TASK (result), &request->error);
   g_main_loop_quit (request->loop);
 }
 
@@ -823,28 +808,23 @@ refresh_account (GoaProvider    *provider,
 static void
 on_initial_sign_in_done (GoaKerberosProvider *self,
                          GAsyncResult        *result,
-                         GSimpleAsyncResult  *operation_result)
+                         GTask               *operation_result)
 {
-  GError    *error;
-  gboolean   remember_password;
-  GoaObject *object;
+  GError     *error;
+  gboolean    remember_password;
+  GoaObject  *object;
+  char       *object_path;
 
-  object = g_simple_async_result_get_source_tag (operation_result);
+  object = g_task_get_source_tag (operation_result);
 
   remember_password = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (operation_result),
                                                           "remember-password"));
 
   error = NULL;
-  if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result), &error))
-    {
-      g_simple_async_result_take_error (operation_result, error);
-    }
-  else if (remember_password)
+  object_path = g_task_propagate_pointer (G_TASK (result), &error);
+  if (!g_task_had_error (G_TASK (result)) && remember_password)
     {
       GVariantBuilder  builder;
-      const char      *object_path;
-
-      object_path = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (result));
 
       if (object_path != NULL && object != NULL)
         {
@@ -872,14 +852,16 @@ on_initial_sign_in_done (GoaKerberosProvider *self,
         }
     }
 
-  g_simple_async_result_complete_in_idle (operation_result);
+  g_task_return_boolean (operation_result, TRUE);
+
+  g_free (object_path);
   g_object_unref (operation_result);
 }
 
 static void
 on_system_prompt_answered_for_initial_sign_in (GcrPrompt          *prompt,
                                                GAsyncResult       *result,
-                                               GSimpleAsyncResult *operation_result)
+                                               GTask              *operation_result)
 {
   GoaKerberosProvider *self;
   GCancellable        *cancellable;
@@ -889,9 +871,9 @@ on_system_prompt_answered_for_initial_sign_in (GcrPrompt          *prompt,
   const char          *preauth_source;
   GcrSecretExchange   *secret_exchange;
 
-  self = GOA_KERBEROS_PROVIDER (g_async_result_get_source_object (G_ASYNC_RESULT (operation_result)));
+  self = GOA_KERBEROS_PROVIDER (g_task_get_source_object (operation_result));
   principal = g_object_get_data (G_OBJECT (operation_result), "principal");
-  cancellable = g_object_get_data (G_OBJECT (operation_result), "cancellable");
+  cancellable = g_task_get_cancellable (operation_result);
 
   /* We currently don't prompt the user to choose a preauthentication source during initial sign in
    * so we assume there's no preauthentication source
@@ -906,11 +888,15 @@ on_system_prompt_answered_for_initial_sign_in (GcrPrompt          *prompt,
       gcr_system_prompt_close (GCR_SYSTEM_PROMPT (prompt), NULL, NULL);
 
       if (error != NULL)
-        g_simple_async_result_take_error (operation_result, error);
+        {
+          g_task_return_error (operation_result, error);
+        }
       else
-        g_cancellable_cancel (cancellable);
+        {
+          g_cancellable_cancel (cancellable);
+          g_task_return_error_if_cancelled (operation_result);
+        }
 
-      g_simple_async_result_complete_in_idle (operation_result);
       g_object_unref (operation_result);
       return;
     }
@@ -941,21 +927,19 @@ on_system_prompt_answered_for_initial_sign_in (GcrPrompt          *prompt,
 static void
 on_system_prompt_open_for_initial_sign_in (GcrSystemPrompt     *system_prompt,
                                            GAsyncResult        *result,
-                                           GSimpleAsyncResult  *operation_result)
+                                           GTask               *operation_result)
 {
   GCancellable *cancellable;
   GcrPrompt    *prompt;
   GError       *error;
 
-  cancellable = g_object_get_data (G_OBJECT (operation_result), "cancellable");
+  cancellable = g_task_get_cancellable (operation_result);
   error = NULL;
   prompt = gcr_system_prompt_open_finish (result, &error);
 
   if (prompt == NULL)
     {
-      g_simple_async_result_take_error (operation_result, error);
-
-      g_simple_async_result_complete_in_idle (operation_result);
+      g_task_return_error (operation_result, error);
       g_object_unref (operation_result);
 
       return;
@@ -979,22 +963,14 @@ perform_initial_sign_in (GoaKerberosProvider *self,
                          SignInRequest       *request)
 {
 
-  GSimpleAsyncResult *operation_result;
-  GCancellable       *cancellable;
+  GTask        *operation_result;
+  GCancellable *cancellable;
 
   cancellable = g_cancellable_new ();
 
-  operation_result = g_simple_async_result_new (G_OBJECT (self),
-                                                (GAsyncReadyCallback)
-                                                on_account_signed_in ,
-                                                request,
-                                                object);
-  g_simple_async_result_set_check_cancellable (operation_result, cancellable);
+  operation_result = g_task_new (G_OBJECT (self), cancellable, (GAsyncReadyCallback) on_account_signed_in, request);
+  g_task_set_source_tag (operation_result, object);
 
-  g_object_set_data_full (G_OBJECT (operation_result),
-                          "cancellable",
-                          g_object_ref (cancellable),
-                          g_object_unref);
   g_object_set_data (G_OBJECT (operation_result),
                      "principal",
                      (gpointer)
@@ -1622,8 +1598,9 @@ out:
 }
 
 static void
-sign_in_thread (GSimpleAsyncResult  *result,
+sign_in_thread (GTask               *task,
                 GoaKerberosProvider *self,
+                gpointer             task_data G_GNUC_UNUSED,
                 GCancellable        *cancellable)
 {
   const char *identifier;
@@ -1632,24 +1609,24 @@ sign_in_thread (GSimpleAsyncResult  *result,
   char *object_path;
   GError *error;
 
-  identifier = g_simple_async_result_get_source_tag (result);
-  password = g_object_get_data (G_OBJECT (result), "password");
-  preauth_source = g_object_get_data (G_OBJECT (result), "preauth-source");
+  identifier = g_task_get_source_tag (task);
+  password = g_object_get_data (G_OBJECT (task), "password");
+  preauth_source = g_object_get_data (G_OBJECT (task), "preauth-source");
 
   error = NULL;
   object_path = sign_in_identity_sync (self, identifier, password, preauth_source, cancellable, &error);
 
   if (object_path == NULL)
-    g_simple_async_result_take_error (result, error);
+    g_task_return_error (task, error);
   else
-    g_simple_async_result_set_op_res_gpointer (result, object_path, NULL);
+    g_task_return_pointer (task, object_path, NULL);
 }
 
 
 static void
 on_object_manager_created (gpointer             object,
                            GAsyncResult        *result,
-                           GSimpleAsyncResult  *operation_result)
+                           gpointer             unused G_GNUC_UNUSED)
 {
   GDBusObjectManager *manager;
   GError *error;
@@ -1694,7 +1671,7 @@ ensure_object_manager (void)
 static void
 on_identity_manager_created (gpointer             identity,
                              GAsyncResult        *result,
-                             GSimpleAsyncResult  *operation_result)
+                             gpointer             unused G_GNUC_UNUSED)
 {
   GoaIdentityServiceManager *manager;
   GError *error;
