@@ -82,6 +82,8 @@ static guint goa_provider_get_credentials_generation_real (GoaProvider *self);
 static GIcon *goa_provider_get_provider_icon_real (GoaProvider *self,
                                                    GoaObject   *object);
 
+static void goa_provider_initialize_real (GoaProvider *self);
+
 static void goa_provider_remove_account_real (GoaProvider          *self,
                                               GoaObject            *object,
                                               GCancellable         *cancellable,
@@ -246,6 +248,7 @@ goa_provider_class_init (GoaProviderClass *klass)
   klass->ensure_credentials_sync = goa_provider_ensure_credentials_sync_real;
   klass->get_credentials_generation = goa_provider_get_credentials_generation_real;
   klass->get_provider_icon = goa_provider_get_provider_icon_real;
+  klass->initialize = goa_provider_initialize_real;
   klass->remove_account = goa_provider_remove_account_real;
   klass->remove_account_finish = goa_provider_remove_account_finish_real;
   klass->show_account = goa_provider_show_account_real;
@@ -415,6 +418,21 @@ goa_provider_get_provider_features (GoaProvider *self)
 
 /* ---------------------------------------------------------------------------------------------------- */
 
+void
+goa_provider_initialize (GoaProvider *self)
+{
+  g_return_if_fail (GOA_IS_PROVIDER (self));
+
+  GOA_PROVIDER_GET_CLASS (self)->initialize (self);
+}
+
+static void
+goa_provider_initialize_real (GoaProvider *self)
+{
+}
+
+/* ---------------------------------------------------------------------------------------------------- */
+
 /**
  * goa_provider_add_account:
  * @self: A #GoaProvider.
@@ -720,13 +738,8 @@ goa_provider_ensure_credentials (GoaProvider          *self,
   g_return_if_fail (GOA_IS_OBJECT (object));
   g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
 
-  task = g_task_new (self,
-                     cancellable,
-                     callback,
-                     user_data);
-  g_task_set_task_data (task,
-                        ensure_credentials_data_new (object),
-                        (GDestroyNotify) ensure_credentials_data_free);
+  task = g_task_new (self, cancellable, callback, user_data);
+  g_task_set_task_data (task, ensure_credentials_data_new (object), (GDestroyNotify) ensure_credentials_data_free);
   g_task_set_source_tag (task, goa_provider_ensure_credentials);
   g_task_run_in_thread (task, ensure_credentials_in_thread_func);
 
