@@ -690,7 +690,7 @@ goa_utils_get_credentials (GoaProvider    *provider,
   GVariant *credentials = NULL;
   GoaAccount *account = NULL;
   gboolean ret = FALSE;
-  const gchar *username;
+  gchar *username = NULL;
   gchar *password = NULL;
 
   credentials = goa_utils_lookup_credentials_sync (provider,
@@ -701,7 +701,7 @@ goa_utils_get_credentials (GoaProvider    *provider,
     goto out;
 
   account = goa_object_get_account (object);
-  username = goa_account_get_identity (account);
+  username = goa_account_dup_identity (account);
 
   if (!g_variant_lookup (credentials, id, "s", &password))
     {
@@ -712,7 +712,10 @@ goa_utils_get_credentials (GoaProvider    *provider,
     }
 
   if (out_username)
-    *out_username = g_strdup (username);
+    {
+      *out_username = username;
+      username = NULL;
+    }
 
   if (out_password)
     {
@@ -725,6 +728,7 @@ goa_utils_get_credentials (GoaProvider    *provider,
 out:
   g_clear_object (&account);
   g_clear_pointer (&credentials, (GDestroyNotify) g_variant_unref);
+  g_free (username);
   g_free (password);
   return ret;
 }
